==> kvpnc_0.8.5.1.orig.tar.gz: kvpnc-0.8.5.1/src/importopenvpnprofiledialog.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef IMPORTOPENVPNPROFILEDIALOG_H
#define IMPORTOPENVPNPROFILEDIALOG_H

#include <kdialogbase.h>
#include "importopenvpnprofiledialogbase.h"
#include "vpnaccountdata.h"
#include "kvpncconfig.h"

/**
@author Christoph Thielecke
*/
class ImportOpenvpnProfileDialog : public KDialogBase
{
Q_OBJECT
public:
	ImportOpenvpnProfileDialog( KVpncConfig *config, QWidget *parent, const QString& caption);
	~ImportOpenvpnProfileDialog();
	
	void canAccept();
	QString filename;
	bool importOk;
	VpnAccountData *acc;
	ImportOpenvpnProfileDialogBase *main;
	
public slots:
	void accept();	

private:
	KVpncConfig* config;
	QString Pkcs12CertFile;
	QString CertPath;
};

#endif

==> kvpnc_0.8.9.orig.tar.gz: kvpnc-0.8.9.orig/src/importopenvpnprofiledialog.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef IMPORTOPENVPNPROFILEDIALOG_H
#define IMPORTOPENVPNPROFILEDIALOG_H

#include <kdialogbase.h>
#include "importopenvpnprofiledialogbase.h"
#include "vpnaccountdata.h"
#include "kvpncconfig.h"

/**
@author Christoph Thielecke
*/
class ImportOpenvpnProfileDialog : public KDialogBase
{
Q_OBJECT
public:
	ImportOpenvpnProfileDialog( KVpncConfig *config, QWidget *parent, const QString& caption, QString file);
	~ImportOpenvpnProfileDialog();
	
	void canAccept();
	QString filename;
	bool importOk;
	VpnAccountData *acc;
	ImportOpenvpnProfileDialogBase *main;
	
public slots:
	void accept();	

private:
	KVpncConfig* config;
	QString Pkcs12CertFile;
	QString CertPath;
};

#endif
